==> appletrun-1.9.5.tar.gz: appletrun-1.9.5/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['appletrun']

package_data = \
{'': ['*']}

entry_points = \
{'console_scripts': ['appletrun = appletrun.__main__:main']}

setup_kwargs = {
    'name': 'appletrun',
    'version': '1.9.5',
    'description': '✨ Appletrun takes java file as input and runs the applet instantly with out manually compilation and html files',
    'long_description': '# APPLETRUN\n\n![](https://img.shields.io/pypi/v/appletrun?style=for-the-badge)\n![](https://img.shields.io/apm/l/vim-mode?style=for-the-badge)\n![](https://img.shields.io/badge/requires-Java%20%3C%3D%208-red?style=for-the-badge)\n\nAppletRun runs applet code from given java file in a new window\n\n## 👉 Installation\n\n```\npip install appletrun\n```\n\nif not working try `python -m pip install appletrun` or `python3 -m pip install appletrun`\n\n## 👉 Usage\n\n```\n appletrun nameOfFile.java\n```\n\n<p align="center">\n<img src="https://user-images.githubusercontent.com/52039218/127250568-51bfd770-49c3-4d32-9da3-18627d9abde3.gif"/>\n </p>\n\n## 👉 Issues\n\nIf you found any bugs or issue post here\nhttps://github.com/Royal-lobster/appletrun-python/issues\n',
    'author': 'Royal-lobster',
    'author_email': 'srujangs8@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/Royal-lobster/appletrun-python',
    'packages': packages,
    'package_data': package_data,
    'entry_points': entry_points,
    'python_requires': '>=3.0,<4.0',
}


setup(**setup_kwargs)

==> appletrun-1.9.6.tar.gz: appletrun-1.9.6/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['appletrun']

package_data = \
{'': ['*']}

entry_points = \
{'console_scripts': ['appletrun = appletrun.__main__:main']}

setup_kwargs = {
    'name': 'appletrun',
    'version': '1.9.6',
    'description': '✨ Appletrun takes java file as input and runs the applet instantly with out manual compilation and html files',
    'long_description': '# APPLETRUN\n\n![](https://img.shields.io/pypi/v/appletrun?style=for-the-badge)\n![](https://img.shields.io/apm/l/vim-mode?style=for-the-badge)\n![](https://img.shields.io/badge/requires-Java%20%3C%3D%208-red?style=for-the-badge)\n\nAppletRun runs applet code from given java file in a new window\n\n## 👉 Installation\n\n```\npip install appletrun\n```\n\nif not working try `python -m pip install appletrun` or `python3 -m pip install appletrun`\n\n## 👉 Usage\n\n```\n appletrun nameOfFile.java\n```\n\n<p align="center">\n<img src="https://user-images.githubusercontent.com/52039218/127250568-51bfd770-49c3-4d32-9da3-18627d9abde3.gif"/>\n </p>\n\n## 👉 Issues\n\nIf you found any bugs or issue post here\nhttps://github.com/Royal-lobster/appletrun-python/issues\n',
    'author': 'Royal-lobster',
    'author_email': 'srujangs8@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/Royal-lobster/appletrun-python',
    'packages': packages,
    'package_data': package_data,
    'entry_points': entry_points,
    'python_requires': '>=3.0,<4.0',
}


setup(**setup_kwargs)
